@@ -1,8 +1,6 @@
 /* debugger.c: Fuse's monitor/debugger
    Copyright (c) 2002-2016 Philip Kendall
 
-   $Id: debugger.c 5677 2016-07-09 13:58:02Z fredm $
-
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
@@ -30,7 +28,7 @@
 #include "event.h"
 #include "fuse.h"
 #include "infrastructure/startup_manager.h"
-#include "memory.h"
+#include "memory_pages.h"
 #include "mempool.h"
 #include "periph.h"
 #include "ui/ui.h"
