@@ -3,8 +3,6 @@
    Copyright (c) 2015 Stuart Brady
    Copyright (c) 2016 Sergio Baldoví
 		 
-   $Id: zxcf.c 5677 2016-07-09 13:58:02Z fredm $
-
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
@@ -35,7 +33,7 @@
 #include "ide.h"
 #include "infrastructure/startup_manager.h"
 #include "machine.h"
-#include "memory.h"
+#include "memory_pages.h"
 #include "module.h"
 #include "periph.h"
 #include "settings.h"
@@ -176,23 +174,11 @@ zxcf_reset( int hard_reset GCC_UNUSED )
   libspectrum_ide_reset( zxcf_idechn );
 }
 
-static int
-zxcf_commit_wrapper( libspectrum_ide_unit unit )
-{
-  if( unit != LIBSPECTRUM_IDE_MASTER ) {
-    ui_error( UI_ERROR_ERROR, "%s:%d: unit is %d, not LIBSPECTRUM_IDE_MASTER",
-	      __FILE__, __LINE__, unit );
-    abort();
-  }
-
-  return zxcf_commit();
-}
-
 int
 zxcf_insert( const char *filename )
 {
   return ide_insert( filename, zxcf_idechn, LIBSPECTRUM_IDE_MASTER,
-		     zxcf_commit_wrapper, &settings_current.zxcf_pri_file,
+		     &settings_current.zxcf_pri_file,
 		     UI_MENU_ITEM_MEDIA_IDE_ZXCF_EJECT );
 }
 
@@ -209,7 +195,7 @@ zxcf_commit( void )
 int
 zxcf_eject( void )
 {
-  return ide_eject( zxcf_idechn, LIBSPECTRUM_IDE_MASTER, zxcf_commit_wrapper,
+  return ide_eject( zxcf_idechn, LIBSPECTRUM_IDE_MASTER,
 		    &settings_current.zxcf_pri_file,
 		    UI_MENU_ITEM_MEDIA_IDE_ZXCF_EJECT );
 }
@@ -294,17 +280,12 @@ zxcf_ide_write( libspectrum_word port, libspectrum_byte data )
 static void
 zxcf_memory_map( void )
 {
-  int i;
+  int map_read;
 
   if( !settings_current.zxcf_active ) return;
 
-  if( !settings_current.zxcf_upload ) {
-    for( i = 0; i < MEMORY_PAGES_IN_16K; i++ )
-      memory_map_read[i] = zxcf_memory_map_romcs[i];
-  }
-
-  for( i = 0; i < MEMORY_PAGES_IN_16K; i++ )
-    memory_map_write[i] = zxcf_memory_map_romcs[i];
+  map_read = !settings_current.zxcf_upload;
+  memory_map_16k_read_write( 0x0000, zxcf_memory_map_romcs, 0, map_read, 1 );
 }
 
 static void
