@@ -1,8 +1,6 @@
 /* pokemem.c: help with handling pokes
    Copyright (c) 2011-2015 Philip Kendall, Sergio Baldoví
 
-   $Id: pokemem.c 5508 2016-05-21 11:52:29Z fredm $
-
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
@@ -30,7 +28,7 @@
 
 #include "compat.h"
 #include "machine.h"
-#include "memory.h"
+#include "memory_pages.h"
 #include "pokemem.h"
 #include "spectrum.h"
 #include "utils.h"
