@@ -3,8 +3,6 @@
    Copyright (c) 2015 UB880D
    Copyright (c) 2016 Fredrick Meunier
 
-   $Id: tape.c 5677 2016-07-09 13:58:02Z fredm $
-
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
@@ -40,7 +38,7 @@
 #include "infrastructure/startup_manager.h"
 #include "loader.h"
 #include "machine.h"
-#include "memory.h"
+#include "memory_pages.h"
 #include "peripherals/ula.h"
 #include "settings.h"
 #include "sound.h"
@@ -823,6 +821,7 @@ tape_next_edge( libspectrum_dword last_tstates, int type, void *user_data )
 
   /* Invert the microphone state */
   if( edge_tstates ||
+      !( flags & LIBSPECTRUM_TAPE_FLAGS_NO_EDGE ) ||
       ( flags & ( LIBSPECTRUM_TAPE_FLAGS_STOP |
                   LIBSPECTRUM_TAPE_FLAGS_LEVEL_LOW |
                   LIBSPECTRUM_TAPE_FLAGS_LEVEL_HIGH ) ) ) {
