@@ -4,8 +4,6 @@
    Copyright (c) 2015 Gergely Szasz
    Copyright (c) 2015 Sergio Baldoví
 
-   $Id: z80_ops.c 5556 2016-05-30 11:13:39Z fredm $
-
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
@@ -33,7 +31,7 @@
 #include "debugger/debugger.h"
 #include "event.h"
 #include "machine.h"
-#include "memory.h"
+#include "memory_pages.h"
 #include "periph.h"
 #include "peripherals/disk/beta.h"
 #include "peripherals/disk/didaktik.h"
@@ -60,8 +58,7 @@ static int z80_cbxx( libspectrum_byte opcode2 );
 static int z80_ddxx( libspectrum_byte opcode2 );
 static int z80_edxx( libspectrum_byte opcode2 );
 static int z80_fdxx( libspectrum_byte opcode2 );
-static void z80_ddfdcbxx( libspectrum_byte opcode3,
-			  libspectrum_word tempaddr );
+static void z80_ddfdcbxx( libspectrum_byte opcode3 );
 #endif				/* #ifndef HAVE_ENOUGH_MEMORY */
 
 /* Certain features (eg RZX playback trigged interrupts, the debugger,
@@ -386,7 +383,7 @@ z80_fdxx( libspectrum_byte opcode2 )
 }
 
 static void
-z80_ddfdcbxx( libspectrum_byte opcode3, libspectrum_word tempaddr )
+z80_ddfdcbxx( libspectrum_byte opcode3 )
 {
   switch(opcode3) {
 #include "z80/z80_ddfdcb.c"
